import { OpenAPIV2 } from "openapi-types";
import { ReferenceMetadata } from "./util.js";
import { DiffClient } from "./diff-client.js";
/** The registry to look up the name within. */
export declare enum RegistryKind {
    Definition = 0,
    Parameter = 1,
    Response = 2,
    SecurityDefinition = 3
}
/** A class which contains all definitions which can be referenced in a spec. */
export declare class DefinitionRegistry {
    #private;
    private data;
    /** The key is the parent class and the values are the set of child classes that derive from the parent. */
    private polymorphicMap;
    private unresolvedReferences;
    private providedPaths;
    private referenceStack;
    private referenceMap;
    private currentPath;
    private client;
    constructor(map: Map<string, OpenAPIV2.Document>, client: DiffClient);
    /** Get a collection. */
    getCollection(registry: RegistryKind): any;
    getRegistryName(registry: RegistryKind): string;
    /** Get a flattened collection. */
    getFlattenedCollection(registry: RegistryKind): any;
    /** Search a registry for a specific key. */
    get(meta: ReferenceMetadata): any | undefined;
    /** Logs a reference to an item. */
    countReference(path: string, name: string, registry: RegistryKind): void;
    /** Logs an unresolved reference. */
    logUnresolvedReference(ref: any): void;
    /** Returns unresolved references. */
    getUnresolvedReferences(): string[];
    /** Returns unreferenced items. */
    getUnreferenced(): Map<RegistryKind, string[]>;
    /** Returns the total number of unreferenced definitions. */
    getUnreferencedTotal(): number;
    /** Returns a list of references from the definition-gathering phase. */
    getReferences(key: string): string[];
}
//# sourceMappingURL=definitions.d.ts.map