import { OpenAPIV2 } from "openapi-types";
import { RegistryKind } from "./definitions.js";
import { DiffClient } from "./diff-client.js";
/** A class for parsing Swagger files into an expanded, normalized form. */
export declare class SwaggerParser {
    #private;
    private parameterizedHost?;
    private defaultConsumes?;
    private defaultProduces?;
    private errorSchemas;
    private host?;
    private result;
    private defRegistry?;
    private client?;
    private swaggerMap?;
    private currentPath?;
    /**
     * Creates a new SwaggerParser instance asynchronously.
     * @param paths the path or paths to load
     * @param args arguments
     * @returns initialized SwaggerParser instance
     */
    static create(paths: string | string[], rootPath: string | undefined, client: DiffClient): Promise<SwaggerParser>;
    /** Special handling for the root of a Swagger object. */
    parse(): SwaggerParser;
    /** Get the parsed result as a JSON object. */
    asJSON(): any;
    /** Returns the error schemas discovered by the parser. */
    getErrorSchemas(): Map<string, OpenAPIV2.SchemaObject>;
    /** Returns the unresolved references discovered by the parser. */
    getUnresolvedReferences(): string[];
    /** Returns unreferenced items. */
    getUnreferenced(): Map<RegistryKind, string[]>;
    /** Returns the total number of unreferenced definitions. */
    getUnreferencedTotal(): number;
}
//# sourceMappingURL=parser.d.ts.map