import { RuleResult } from "./rules.js";
function getParameter(source, path) {
    if (!source)
        return undefined;
    let current = source;
    for (const segment of path) {
        current = current[segment];
    }
    return current;
}
/**
 * Ignores a diff in the minLength property on the api-version parameter only.
 */
export function ignoreApiVersionMinLengthRule(data, lhs, rhs) {
    if (!data.path)
        return;
    const path = data.path.join(".");
    const regex = /parameters\.(\d+)\.minLength/;
    const match = path.match(regex);
    if (!match)
        return;
    const paramPath = data.path.slice(0, -1);
    const source = data.lhs !== undefined ? lhs : rhs;
    const param = getParameter(source, paramPath);
    if (!param) {
        throw new Error(`Parameter not found at path: ${paramPath.join(".")}`);
    }
    if (param.name === "api-version")
        return RuleResult.NoViolation;
}
//# sourceMappingURL=ignore-api-version-min-length.js.map