import { RuleResult } from "./rules.js";
import { toSorted } from "../util.js";
function getParameter(source, path) {
    if (!source)
        return undefined;
    let current = source;
    for (const segment of path) {
        current = current[segment];
    }
    return current;
}
/**
 * Ignores array changes if the arrays are actually the same. This can occur due to
 * sorting differences, for example.
 */
export function ignoreEquivalentArrays(data, lhs, rhs) {
    if (!data.path)
        return;
    if (data.path.length < 2)
        return;
    if (data.kind != "E")
        return;
    const lastPath = data.path.slice(-1)[0];
    // if lastPath is a number, it's an array index
    const isArray = !isNaN(Number(lastPath));
    if (!isArray)
        return;
    const arrayPath = data.path.slice(0, -1);
    const lhsArray = getParameter(lhs, arrayPath);
    const rhsArray = getParameter(rhs, arrayPath);
    // if arrays are both arrays of string and are equivalent when sorted, then there's no violation
    if (!lhsArray || !rhsArray)
        return;
    if (!lhsArray.every((x) => typeof x === "string") ||
        !rhsArray.every((x) => typeof x === "string"))
        return;
    if (toSorted(lhsArray).join() === toSorted(rhsArray).join()) {
        return RuleResult.NoViolation;
    }
}
//# sourceMappingURL=ignore-equivalent-arrays.js.map