import { RuleResult } from "./rules.js";
function getParameter(source, path) {
    if (!source)
        return undefined;
    let current = source;
    for (const segment of path) {
        current = current[segment];
    }
    return current;
}
/**
 * Ignores a diff when "format: uri" is added to a parameter is was marked "x-ms-skip-url-encoding".
 */
export function ignoreFormatUriRule(data, lhs, _) {
    if (!data.path)
        return;
    if (data.kind !== "N")
        return;
    const path = data.path.join(".");
    const regex = /parameters\.(\d+)\.format/;
    const match = path.match(regex);
    if (!match)
        return;
    const paramPath = data.path.slice(0, -1);
    const param = getParameter(lhs, paramPath);
    if (!param) {
        throw new Error(`Parameter not found at path: ${paramPath.join(".")}`);
    }
    const skipUrlEncoding = param["x-ms-skip-url-encoding"];
    if (skipUrlEncoding && skipUrlEncoding === true) {
        return RuleResult.NoViolation;
    }
}
//# sourceMappingURL=ignore-format-uri.js.map