import { ignoreSwaggerPropertiesRule } from "./ignore-swagger-properties.js";
import { ignoreIrrelevantResponsePropertiesRule } from "./ignore-irrelevant-response-properties.js";
import { ignoreXMsErrorCodeHeaderRule } from "./ignore-x-ms-error-code-header.js";
import { ignoreApiVersionMinLengthRule } from "./ignore-api-version-min-length.js";
import { ignoreFormatUriRule } from "./ignore-format-uri.js";
import { ignoreNextLinkFormatUriRule } from "./ignore-next-link-format-uri.js";
import { compareErrorsRule } from "./compare-errors.js";
import { flagTypeDifferencesRule } from "./flag-type-differences.js";
import { compareXMsEnumRule } from "./compare-x-ms-enum.js";
import { compareResponseRequiredRule } from "./compare-response-required.js";
import { compareRequestRequiredRule } from "./compare-request-required.js";
import { ignoreSwaggerDefinitionsRule } from "./ignore-swagger-definitions.js";
import { compareXMsIdentifiersRule } from "./compare-x-ms-identifiers.js";
import { ignoreXMsExamplesRule } from "./ignore-x-ms-examples.js";
import { pathAddedRule } from "./path-added.js";
import { pathRemovedRule } from "./path-removed.js";
import { responseAddedRule } from "./response-added.js";
import { responseRemovedRule } from "./response-removed.js";
import { ignoreTagsRule } from "./ignore-tags.js";
import { ignoreEquivalentArrays } from "./ignore-equivalent-arrays.js";
/** Determines whether a diff rule applies and confirms an allowed or disallowed scenario. */
export var RuleResult;
(function (RuleResult) {
    /** The rule applies and flags a verified violation. Stop processing other rules for this diff. */
    RuleResult["FlaggedViolation"] = "F";
    /** No rule handled the diff, so it is assumed to be a violation. */
    RuleResult["AssumedViolation"] = "A";
    /** Rule applies and verifies this is not a violation. Stop processing other rules for this diff. */
    RuleResult["NoViolation"] = "N";
    /** Rule was a flagged or assumed violation, but manually suppressed. */
    RuleResult["Suppressed"] = "S";
})(RuleResult || (RuleResult = {}));
/** Returns the list of rules that should be applied, modified by any options. */
export function getApplicableRules(args) {
    let rules = [
        ignoreEquivalentArrays,
        ignoreSwaggerPropertiesRule,
        ignoreIrrelevantResponsePropertiesRule,
        ignoreXMsErrorCodeHeaderRule,
        ignoreXMsExamplesRule,
        ignoreApiVersionMinLengthRule,
        ignoreFormatUriRule,
        ignoreNextLinkFormatUriRule,
        compareXMsIdentifiersRule,
        compareErrorsRule,
        compareXMsEnumRule,
        flagTypeDifferencesRule,
        compareResponseRequiredRule,
        compareRequestRequiredRule,
        pathAddedRule,
        pathRemovedRule,
        responseAddedRule,
        responseRemovedRule,
        ignoreTagsRule,
    ];
    const preserveDefinitions = args["preserve-definitions"];
    if (!preserveDefinitions) {
        rules.push(ignoreSwaggerDefinitionsRule);
    }
    return rules;
}
//# sourceMappingURL=rules.js.map