import { RegistryKind } from "./definitions.js";
export interface ReferenceMetadata {
    /** Short name of the reference. This is not sufficient to avoid collisions but it often useful. */
    name: string;
    /** The registry this reference points to. */
    registry: RegistryKind;
    /** The fully expanded path to the source file. */
    fullPath: string;
    /** The fully expanded reference. */
    expandedRef: string;
}
/**
 * Compile various sources of path information into a canonical set of
 * reference metadata.
 * @param refs The $ref value to parse.
 * @param filePath A file path to use when resolving relative paths.
 */
export declare function parseReference(ref: string): ReferenceMetadata | undefined;
export declare function isReference(value: any): boolean;
export declare function loadPaths(paths: string[], rootPath: string | undefined, args: any): Promise<Map<string, any>>;
/**
 * Load a Swagger file with paths normalized and relative references expanded into full-qualified
 * ones. If the file is not a Swagger file, it will return undefined.
 */
export declare function loadSwaggerFile(sourcePath: string, rootPath: string | undefined): Promise<any | undefined>;
/**
 * Extracts from the referenced file any file references from $ref
 * usages. Returns an array of file paths that are referenced. Will
 * recursively search for references in the referenced files. Ignores
 * examples.
 * @param data The JSON data to search for references.
 * @param path The path to the file.
 * @returns An array of file paths that are referenced.
 */
export declare function extractFileReferences(path: string, rootPath: string | undefined): Promise<string[]>;
/** Converts a single value or array to an array. */
export declare function forceArray<T>(value: T | T[]): T[];
/**
 * Turn a relative path into a fully-qualified resolved path.
 * If the path is relative, the root path must be provided.
 */
export declare function getResolvedPath(targetPath: string, rootPath?: string): string;
/**
 * Creates a sorted copy of an array without modifying the original array.
 * @param array The array to sort.
 * @param compareFn Optional. A function that defines the sort order.
 * @returns A new array that is sorted.
 */
export declare function toSorted<T>(array: T[], compareFn?: (a: T, b: T) => number): T[];
/**
 * Convert path segments into a flatted, URL-encoded path string.
 */
export declare function getUrlEncodedPath(segments: string[] | undefined): string | undefined;
/**
 * Returns the string key for the `RegistryKind` enum.
 */
export declare function getRegistryName(kind: RegistryKind): string;
//# sourceMappingURL=util.d.ts.map